/*
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2008-present Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus;

import java.util.List;
import java.util.Map;

import org.sonatype.nexus.blobstore.api.BlobStoreConfiguration;
import org.sonatype.nexus.common.script.ScriptApi;

/**
 * BlobStore provisioning capabilities of the repository manager.
 * @since 3.0
 */
public interface BlobStoreApi
    extends ScriptApi
{
  default String getName() {
    return "blobStore";
  }

  /**
   * Create a new File based BlobStore.
   * 
   * @param name the name for the new BlobStore
   * @param path the path where the BlobStore should store data
   */
  BlobStoreConfiguration createFileBlobStore(String name, String path);

  /**
   * Create a new BlobStore group.
   *
   * @param name the name for the new BlobStore
   * @param memberNames name of the member BlobStores
   * @param fillPolicy name of the fill policy
   * @since 3.14
   */
  BlobStoreConfiguration createBlobStoreGroup(String name, List<String> memberNames, String fillPolicy);

  /**
   * Create a new S3 based BlobStore.
   *
   * @param name the name for the new BlobStore
   * @param config the configuration map for the new blobstore
   * @since 3.6
   */
  BlobStoreConfiguration createS3BlobStore(String name, Map<String, String> config);
}
