/*
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2008-present Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.orient;

import com.orientechnologies.orient.core.db.document.ODatabaseDocumentTx;

/**
 * Database pool.
 *
 * @since 3.0
 */
public interface DatabasePool
{
  /**
   * Returns the name of this database pool.
   */
  String getName();

  /**
   * Attempt to open a connection to the database.
   */
  ODatabaseDocumentTx acquire();

  /**
   * Returns the number of available connections in the pool.
   *
   * @since 3.14
   */
  int getAvailableCount();

  /**
   * Returns the current number of connections in the pool.
   *
   * @since 3.14
   */
  int getPoolSize();

  /**
   * Close the database pool.
   */
  void close();
}
