/*
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2008-present Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.orient.entity.action;

import org.sonatype.goodies.testsupport.TestSupport;

import org.junit.Test;

import static com.google.common.collect.Sets.newHashSet;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.anyOf;
import static org.hamcrest.Matchers.equalTo;
import static org.hamcrest.Matchers.is;
import static org.sonatype.nexus.orient.entity.action.QueryUtils.buildIn;

public class QueryUtilsTest
    extends TestSupport
{
  @Test(expected = NullPointerException.class)
  public void testBuildPredicate_NullArray() {
    QueryUtils.buildPredicate((String[]) null);
  }

  @Test(expected = IllegalArgumentException.class)
  public void testBuildPredicate_EmptyArray() {
    QueryUtils.buildPredicate(new String[0]);
  }

  @Test
  public void testBuildPredicate_SingleProperty() {
    assertThat(QueryUtils.buildPredicate("foo"), is("foo = ?"));
  }

  @Test
  public void testBuildPredicate_MultipleProperties() {
    assertThat(QueryUtils.buildPredicate("foo", "bar", "baz"), is("foo = ? AND bar = ? AND baz = ?"));
  }

  @Test
  public void testInPredicate() {
    assertThat(buildIn(newHashSet("foo", "bar")), anyOf(equalTo("['foo','bar']"), equalTo("['bar','foo']")));
  }
}
