/*
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2008-present Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.repository.storage;

import javax.annotation.Nullable;

import org.sonatype.nexus.common.entity.EntityId;
import org.sonatype.nexus.common.entity.EntityMetadata;
import org.sonatype.nexus.common.entity.EntityUpdatedEvent;

import static com.google.common.base.Preconditions.checkNotNull;

/**
 * Asset updated event.
 *
 * @since 3.0
 */
public class AssetUpdatedEvent
    extends EntityUpdatedEvent
    implements AssetEvent
{
  private final String repositoryName;

  private final EntityId componentId;

  public AssetUpdatedEvent(final EntityMetadata metadata, final String repositoryName,
      @Nullable final EntityId componentId)
  {
    super(metadata);
    this.repositoryName = checkNotNull(repositoryName);
    this.componentId = componentId;
  }

  public String getRepositoryName() {
    return repositoryName;
  }

  @Nullable
  public EntityId getComponentId() {
    return componentId;
  }

  public EntityId getAssetId() {
    return getId();
  }

  public Asset getAsset() {
    return getEntity();
  }
}
