/*
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2008-present Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.repository.view;

import java.util.Collections;

import org.sonatype.goodies.testsupport.TestSupport;
import org.sonatype.nexus.repository.Repository;

import org.junit.Before;
import org.junit.Test;
import org.mockito.Mock;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.is;
import static org.hamcrest.Matchers.nullValue;
import static org.sonatype.nexus.repository.view.Router.LOCAL_ATTRIBUTE_PREFIX;

public class RouterTest
    extends TestSupport
{
  private Router underTest;

  @Mock
  Repository repository;

  @Mock
  Request request;

  @Mock
  Route route;

  @Mock
  DefaultRoute defaultRoute;


  @Before
  public void setup() throws Exception {
    underTest = new Router(Collections.singletonList(route), defaultRoute);
  }

  @Test
  public void testMaybeCopyContextAttributes() throws Exception {
    Context existingContext = new Context(repository, request);
    existingContext.getAttributes().set("somekey", "somevalue");
    existingContext.getAttributes().set(LOCAL_ATTRIBUTE_PREFIX + "anotherkey", "anothervalue");
    Context newContext = underTest.maybeCopyContextAttributes(repository, request, existingContext);
    assertThat(newContext.getAttributes().get("somekey"), is("somevalue"));
    assertThat(newContext.getAttributes().get(LOCAL_ATTRIBUTE_PREFIX + "anotherkey"), nullValue());
  }
}
