/*
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2008-present Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.coreui

import org.sonatype.nexus.security.privilege.PrivilegesExist
import org.sonatype.nexus.security.role.RoleNotContainSelf
import org.sonatype.nexus.security.role.RolesExist
import org.sonatype.nexus.security.role.UniqueRoleId
import org.sonatype.nexus.validation.group.Create
import org.sonatype.nexus.validation.group.Update

import groovy.transform.ToString
import org.hibernate.validator.constraints.NotEmpty

/**
 * Role exchange object.
 *
 * @since 3.0
 */
@ToString(includePackage = false, includeNames = true)
@RoleNotContainSelf(id="getId", roleIds="getRoles")
class RoleXO
{
  @NotEmpty
  @UniqueRoleId(groups = Create)
  String id

  @NotEmpty(groups = Update)
  String version

  String source

  @NotEmpty
  String name

  String description

  Boolean readOnly

  @PrivilegesExist(groups = [Create, Update])
  Set<String> privileges

  @RolesExist(groups = [Create, Update])
  Set<String> roles
}
