/*
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2008-present Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.repository.pypi.internal;

import javax.inject.Inject;
import javax.inject.Named;

import org.sonatype.nexus.repository.security.ContentPermissionChecker;
import org.sonatype.nexus.repository.security.SecurityFacetSupport;
import org.sonatype.nexus.repository.security.VariableResolverAdapter;
import org.sonatype.nexus.repository.view.Request;
import org.sonatype.nexus.security.BreadActions;

import static org.sonatype.nexus.repository.pypi.internal.PyPiPathUtils.isSearchRequest;

/**
 * PyPI format security facet.
 *
 * @since 3.1
 */
@Named
public class PyPiSecurityFacet
    extends SecurityFacetSupport
{
  @Inject
  public PyPiSecurityFacet(final PyPiFormatSecurityContributor securityContributor,
                           @Named("simple") final VariableResolverAdapter variableResolverAdapter,
                           final ContentPermissionChecker contentPermissionChecker)
  {
    super(securityContributor, variableResolverAdapter, contentPermissionChecker);
  }

  protected String action(final Request request) {
    if (isSearchRequest(request)) {
      return BreadActions.READ;
    }
    return super.action(request);
  }
}
